import React from 'react';
import { DialogProps } from '@mui/material/Dialog';
export type BasicDialogProps = Omit<DialogProps, 'open'> & {
    /**
     * The title for the screen
     */
    title?: string;
    /**
     * The text to show in the main dialog body
     */
    body?: string;
    /**
     * The function to call when the close button is clicked
     * @returns void
     */
    onClose?: () => void;
    /**
     * The text to show in the close button
     */
    dismissButtonText?: string;
    /**
     * Set the open / closed state of the dialog
     * @default false
     */
    open?: boolean;
};
/**
 * Component that renders a basic dialog with a title, body description, and a close button.
 *
 * @param {BasicDialogProps} props - basic props of Dialog
 *
 * @category Component
 */
export declare const BasicDialog: React.FC<React.PropsWithChildren<React.PropsWithChildren<BasicDialogProps>>>;
