"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReactRouterGuestGuard = void 0;
var react_1 = __importDefault(require("react"));
var react_router_dom_1 = require("react-router-dom");
/**
 * Component that renders a conditional Route. If the user is already authenticated, this route
 * will redirect back to the prior route. If the user is not authenticated, it will render the provided
 * content.
 *
 * @param children The element/route to render if the user is not authenticated
 * @param isAuthenticated Indicates whether the user is authenticated or not
 * @param fallBackUrl URL where to redirect if user is authenticated
 *
 * @category Component
 */
var ReactRouterGuestGuard = function (props) {
    var _a, _b;
    var _c = props.children, children = _c === void 0 ? null : _c, isAuthenticated = props.isAuthenticated, fallBackUrl = props.fallBackUrl;
    var location = (0, react_router_dom_1.useLocation)();
    if (isAuthenticated) {
        var redirectedURL = (_b = (_a = location.state) === null || _a === void 0 ? void 0 : _a.from) !== null && _b !== void 0 ? _b : fallBackUrl;
        return react_1.default.createElement(react_router_dom_1.Navigate, { to: redirectedURL, replace: true });
    }
    return children;
};
exports.ReactRouterGuestGuard = ReactRouterGuestGuard;
